@@ -15,7 +15,14 @@ Including another URLconf
 """
 from django.contrib import admin
 from django.urls import path
+from django.views.generic import RedirectView
+from django.utils.translation import gettext_lazy as _
+
+admin.site.site_header = _("Django Site Warnings")
+admin.site.site_title = _("Django Site Warnings")
 
 urlpatterns = [
+    path('', RedirectView.as_view(url="/admin")),
     path('admin/', admin.site.urls),
 ]
+
